@@ -516,6 +516,13 @@ func MachineVMSizes() []fly.VMSize {
 			MemoryMB: 256,
 			MemoryGB: 0.25,
 		},
+		{
+			Name:     "shared-cpu-1x",
+			CPUClass: "shared",
+			CPUCores: 1,
+			MemoryMB: 1024,
+			MemoryGB: 1,
+		},
 		{
 			Name:     "shared-cpu-2x",
 			CPUClass: "shared",
